@@ -49,7 +49,7 @@ bool HealthCertificateManager::importCertificate(const QByteArray &rawData)
 {
     // check whether we know this certificate already
     for (const auto &c : m_certificates) {
-        if (certificateRawData(c) == rawData) {
+        if (certificateRawData(c.cert) == rawData) {
             return true;
         }
     }
@@ -111,28 +111,11 @@ QVariant HealthCertificateManager::data(const QModelIndex &index, int role) cons
     const auto &v = m_certificates[index.row()];
     switch (role) {
         case Qt::DisplayRole:
-#if HAVE_KHEALTHCERTIFICATE
-            if (v.cert.userType() == qMetaTypeId<KVaccinationCertificate>()) {
-                const auto cert = v.cert.value<KVaccinationCertificate>();
-                if (cert.dose() > 0 && cert.totalDoses() > 0) {
-                    return i18n("Vaccination %1/%2 (%3)", cert.dose(), cert.totalDoses(), cert.name());
-                }
-                return i18n("Vaccination (%1)", cert.name());
-            }
-            if (v.cert.userType() == qMetaTypeId<KTestCertificate>()) {
-                const auto cert = v.cert.value<KTestCertificate>();
-                return i18n("Test %1 (%2)", QLocale().toString(cert.date().isValid() ? cert.date() : cert.certificateIssueDate().date(), QLocale::NarrowFormat), cert.name());
-            }
-            if (v.cert.userType() == qMetaTypeId<KRecoveryCertificate>()) {
-                const auto cert = v.cert.value<KRecoveryCertificate>();
-                return i18n("Recovery (%1)", cert.name());
-            }
-#endif
-            return {};
+            return displayName(v.cert);
         case CertificateRole:
             return v.cert;
         case RawDataRole:
-            return certificateRawData(v);
+            return certificateRawData(v.cert);
         case StorageIdRole:
             return v.name;
     }
@@ -148,6 +131,28 @@ QHash<int, QByteArray> HealthCertificateManager::roleNames() const
     return rns;
 }
 
+QString HealthCertificateManager::displayName(const QVariant &certificate)
+{
+#if HAVE_KHEALTHCERTIFICATE
+    if (certificate.userType() == qMetaTypeId<KVaccinationCertificate>()) {
+        const auto cert = certificate.value<KVaccinationCertificate>();
+        if (cert.dose() > 0 && cert.totalDoses() > 0) {
+            return i18n("Vaccination %1/%2 (%3)", cert.dose(), cert.totalDoses(), cert.name());
+        }
+        return i18n("Vaccination (%1)", cert.name());
+    }
+    if (certificate.userType() == qMetaTypeId<KTestCertificate>()) {
+        const auto cert = certificate.value<KTestCertificate>();
+        return i18n("Test %1 (%2)", QLocale().toString(cert.date().isValid() ? cert.date() : cert.certificateIssueDate().date(), QLocale::NarrowFormat), cert.name());
+    }
+    if (certificate.userType() == qMetaTypeId<KRecoveryCertificate>()) {
+        const auto cert = certificate.value<KRecoveryCertificate>();
+        return i18n("Recovery (%1)", cert.name());
+    }
+#endif
+    return {};
+}
+
 void HealthCertificateManager::loadCertificates()
 {
     beginResetModel();
@@ -174,17 +179,17 @@ void HealthCertificateManager::loadCertificates()
     endResetModel();
 }
 
-QByteArray HealthCertificateManager::certificateRawData([[maybe_unused]] const CertData &certData) const
+QByteArray HealthCertificateManager::certificateRawData([[maybe_unused]] const QVariant &cert)
 {
 #if HAVE_KHEALTHCERTIFICATE
-    if (certData.cert.userType() == qMetaTypeId<KVaccinationCertificate>()) {
-        return certData.cert.value<KVaccinationCertificate>().rawData();
+    if (cert.userType() == qMetaTypeId<KVaccinationCertificate>()) {
+        return cert.value<KVaccinationCertificate>().rawData();
     }
-    if (certData.cert.userType() == qMetaTypeId<KTestCertificate>()) {
-        return certData.cert.value<KTestCertificate>().rawData();
+    if (cert.userType() == qMetaTypeId<KTestCertificate>()) {
+        return cert.value<KTestCertificate>().rawData();
     }
-    if (certData.cert.userType() == qMetaTypeId<KRecoveryCertificate>()) {
-        return certData.cert.value<KRecoveryCertificate>().rawData();
+    if (cert.userType() == qMetaTypeId<KRecoveryCertificate>()) {
+        return cert.value<KRecoveryCertificate>().rawData();
     }
 #endif
     return {};
