@@ -34,19 +34,6 @@ using namespace KAndroidExtras;
 
 using namespace KItinerary;
 
-static QString readFromGadget(const QMetaObject *mo, const QVariant &gadget, const char *propName)
-{
-    const auto propIdx = mo->indexOfProperty(propName);
-    if (propIdx < 0) {
-        return {};
-    }
-    const auto prop = mo->property(propIdx);
-    if (!prop.isValid()) {
-        return {};
-    }
-    return prop.readOnGadget(gadget.constData()).toString();
-}
-
 static KContacts::Address variantToKContactsAddress(const QVariant &obj)
 {
     KContacts::Address address;
@@ -57,13 +44,6 @@ static KContacts::Address variantToKContactsAddress(const QVariant &obj)
         address.setLocality(a.addressLocality());
         address.setRegion(a.addressRegion());
         address.setCountry(a.addressCountry());
-    } else if (std::strcmp(obj.typeName(), "KOSMIndoorMap::OSMAddress") == 0) {
-        const auto mo = QMetaType(obj.userType()).metaObject();
-        address.setStreet(readFromGadget(mo, obj, "street") + QLatin1Char(' ') + readFromGadget(mo, obj, "houseNumber"));
-        address.setPostalCode(readFromGadget(mo, obj, "postalCode"));
-        address.setLocality(readFromGadget(mo, obj, "city"));
-        address.setRegion(readFromGadget(mo, obj, "state"));
-        address.setCountry(readFromGadget(mo, obj, "country"));
     }
     return address;
 }
