@@ -37,8 +37,19 @@ using namespace KItinerary;
 
 ReservationManager::ReservationManager(QObject* parent)
     : QObject(parent)
+    , m_validator(ReservationManager::validator())
 {
-    m_validator.setAcceptedTypes<
+    m_validator.setAcceptOnlyCompleteElements(true);
+
+    loadBatches();
+}
+
+ReservationManager::~ReservationManager() = default;
+
+KItinerary::ExtractorValidator ReservationManager::validator()
+{
+    KItinerary::ExtractorValidator v;
+    v.setAcceptedTypes<
         BoatReservation,
         BusReservation,
         EventReservation,
@@ -49,13 +60,9 @@ ReservationManager::ReservationManager(QObject* parent)
         TrainReservation,
         TouristAttractionVisit
     >();
-    m_validator.setAcceptOnlyCompleteElements(true);
-
-    loadBatches();
+    return v;
 }
 
-ReservationManager::~ReservationManager() = default;
-
 bool ReservationManager::isEmpty() const
 {
     return m_batchToResMap.empty();
@@ -123,50 +130,43 @@ QString ReservationManager::batchesBasePath()
     return QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1StringView("/batches/");
 }
 
-QList<QString>
-ReservationManager::importReservations(const QList<QVariant> &resData) {
-  ExtractorPostprocessor postproc;
-  postproc.setContextDate(QDateTime(QDate::currentDate(), QTime(0, 0)));
-  postproc.process(resData);
+QList<QString> ReservationManager::addReservationsWithPostProcessing(const QList<QVariant> &resData)
+{
+    ExtractorPostprocessor postproc;
+    postproc.setContextDate(QDateTime(QDate::currentDate(), QTime(0, 0)));
+    postproc.process(resData);
 
-  auto data = postproc.result();
-  QList<QString> ids;
-  ids.reserve(data.size());
-  for (auto &res : data) {
-    if (JsonLd::isA<Event>(res)) { // promote Event to EventReservation
-      EventReservation ev;
-      ev.setReservationFor(res);
-      ev.setPotentialAction(res.value<Event>().potentialAction());
-      res = ev;
-    }
-    // TODO show UI asking for time ranges for LodgingBusiness,
-    // FoodEstablishment, etc
+    auto data = postproc.result();
+    QList<QString> ids;
+    ids.reserve(data.size());
+    for (auto &res : data) {
+        if (JsonLd::isA<Event>(res)) { // promote Event to EventReservation
+            EventReservation ev;
+            ev.setReservationFor(res);
+            ev.setPotentialAction(res.value<Event>().potentialAction());
+            res = ev;
+        }
 
-    // filter out non-Reservation objects we can't handle yet
-    if (!m_validator.isValidElement(res)) {
-
-      // check if this is a minimal cancellation element
-      const auto cleanup = qScopeGuard(
-          [this] { m_validator.setAcceptOnlyCompleteElements(true); });
-      m_validator.setAcceptOnlyCompleteElements(false);
-      if (m_validator.isValidElement(res)) {
-        ids += applyPartialUpdate(res);
-        continue;
-      }
-
-      qCWarning(Log) << "Discarding imported element due to validation failure"
-                     << res;
-      continue;
+        ids.push_back(addReservation(res));
     }
 
-    ids.push_back(addReservation(res));
-  }
-
-  return ids;
+    return ids;
 }
 
 QString ReservationManager::addReservation(const QVariant &res, const QString &resIdHint)
 {
+    // deal with partial updates
+    if (!m_validator.isValidElement(res)) {
+        const auto cleanup = qScopeGuard([this] { m_validator.setAcceptOnlyCompleteElements(true); });
+        m_validator.setAcceptOnlyCompleteElements(false);
+        if (m_validator.isValidElement(res)) {
+            const auto ids = applyPartialUpdate(res);
+            return ids.empty() ? QString() : ids.front();
+        }
+        qCWarning(Log) << "Discarding added element due to validation failure" << res;
+        return {};
+    }
+
     // look for matching reservations, or matching batches
     // we need to do that within a +/-24h range, so we find unbound elements too
     // TODO in case this updates the time for an unbound element we need to re-sort, otherwise the prev/next logic fails!
@@ -230,9 +230,9 @@ QString ReservationManager::addReservation(const QVariant &res, const QString &r
     return resId;
 }
 
-void ReservationManager::importReservation(const QVariant &resData)
+void ReservationManager::addReservationWithPostProcessing(const QVariant &resData)
 {
-    importReservations({resData});
+    addReservationsWithPostProcessing({resData});
 }
 
 void ReservationManager::updateReservation(const QString &resId, const QVariant &res)
@@ -465,57 +465,98 @@ void ReservationManager::removeFromBatch(const QString &resId, const QString &ba
     }
 }
 
-QList<QString> ReservationManager::applyPartialUpdate(const QVariant &res) {
-  // validate input
-  if (!JsonLd::canConvert<Reservation>(res)) {
-    return {};
-  }
-  const auto baseRes = JsonLd::convert<Reservation>(res);
-  if (!baseRes.modifiedTime().isValid()) {
-    return {};
-  }
-
-  // look for matching reservations in a 6 month window following the
-  // modification time
-  const auto rangeBegin = baseRes.modifiedTime();
-  const auto rangeEnd = rangeBegin.addDays(6 * 30);
-
-  QList<QString> updatedIds;
-  const auto beginIt =
-      std::lower_bound(m_batches.begin(), m_batches.end(), rangeBegin,
-                       [this](const auto &lhs, const auto &rhs) {
-                         return SortUtil::startDateTime(reservation(lhs)) < rhs;
-                       });
-  for (auto it = beginIt; it != m_batches.end(); ++it) {
-    const auto otherRes = reservation(*it);
-    if (SortUtil::startDateTime(otherRes) > rangeEnd) {
-      break; // no hit
+QVariant ReservationManager::isPartialUpdate(const QVariant &res) const
+{
+    // validate input
+    if (!JsonLd::canConvert<Reservation>(res)) {
+        return {};
     }
-    if (MergeUtil::isSame(res, otherRes)) {
-      // this is actually an update of otherRes!
-      const auto newRes = MergeUtil::merge(otherRes, res);
-      updateReservation(*it, newRes);
-      updatedIds.push_back(*it);
-      continue;
+    const auto baseRes = JsonLd::convert<Reservation>(res);
+    if (!baseRes.modifiedTime().isValid()) {
+        return {};
     }
-    if (MergeUtil::isSameIncidence(res, otherRes)) {
-      // this is a multi-traveler element, check if we have it as one of the
-      // batch elements already
-      const auto &batch = m_batchToResMap.value(*it);
-      for (const auto &batchedId : batch) {
-        const auto batchedRes = reservation(batchedId);
-        if (MergeUtil::isSame(res, batchedRes)) {
-          // this is actually an update of a batched reservation
-          const auto newRes = MergeUtil::merge(otherRes, res);
-          updateReservation(batchedId, newRes);
-          updatedIds.push_back(batchedId);
-          break;
+
+    // look for matching reservations in a 6 month window following the
+    // modification time
+    const auto rangeBegin = baseRes.modifiedTime();
+    const auto rangeEnd = rangeBegin.addDays(6 * 30);
+
+    const auto beginIt = std::lower_bound(m_batches.begin(), m_batches.end(), rangeBegin, [this](const auto &lhs, const auto &rhs) {
+        return SortUtil::startDateTime(reservation(lhs)) < rhs;
+    });
+    for (auto it = beginIt; it != m_batches.end(); ++it) {
+        auto otherRes = reservation(*it);
+        if (SortUtil::startDateTime(otherRes) > rangeEnd) {
+            break; // no hit
+        }
+        if (MergeUtil::isSame(res, otherRes)) {
+            return otherRes;
+        }
+        if (MergeUtil::isSameIncidence(res, otherRes)) {
+            // this is a multi-traveler element, check if we have it as one of the batch elements
+            const auto &batch = m_batchToResMap.value(*it);
+            for (const auto &batchedId : batch) {
+                auto batchedRes = reservation(batchedId);
+                if (MergeUtil::isSame(res, batchedRes)) {
+                    return batchedRes;
+                }
+            }
         }
-      }
     }
-  }
 
-  return updatedIds;
+    return {};
+}
+
+QList<QString> ReservationManager::applyPartialUpdate(const QVariant &res)
+{
+    // validate input
+    if (!JsonLd::canConvert<Reservation>(res)) {
+        return {};
+    }
+    const auto baseRes = JsonLd::convert<Reservation>(res);
+    if (!baseRes.modifiedTime().isValid()) {
+        return {};
+    }
+
+    // look for matching reservations in a 6 month window following the
+    // modification time
+    const auto rangeBegin = baseRes.modifiedTime();
+    const auto rangeEnd = rangeBegin.addDays(6 * 30);
+
+    QList<QString> updatedIds;
+    const auto beginIt = std::lower_bound(m_batches.begin(), m_batches.end(), rangeBegin, [this](const auto &lhs, const auto &rhs) {
+        return SortUtil::startDateTime(reservation(lhs)) < rhs;
+    });
+    for (auto it = beginIt; it != m_batches.end(); ++it) {
+        const auto otherRes = reservation(*it);
+        if (SortUtil::startDateTime(otherRes) > rangeEnd) {
+            break; // no hit
+        }
+        if (MergeUtil::isSame(res, otherRes)) {
+            // this is actually an update of otherRes!
+            const auto newRes = MergeUtil::merge(otherRes, res);
+            updateReservation(*it, newRes);
+            updatedIds.push_back(*it);
+            continue;
+        }
+        if (MergeUtil::isSameIncidence(res, otherRes)) {
+            // this is a multi-traveler element, check if we have it as one of the
+            // batch elements already
+            const auto &batch = m_batchToResMap.value(*it);
+            for (const auto &batchedId : batch) {
+                const auto batchedRes = reservation(batchedId);
+                if (MergeUtil::isSame(res, batchedRes)) {
+                    // this is actually an update of a batched reservation
+                    const auto newRes = MergeUtil::merge(otherRes, res);
+                    updateReservation(batchedId, newRes);
+                    updatedIds.push_back(batchedId);
+                    break;
+                }
+            }
+        }
+    }
+
+    return updatedIds;
 }
 
 QString ReservationManager::previousBatch(const QString &batchId) const
