@@ -326,7 +326,7 @@ std::vector<TimelineElement>::iterator TimelineModel::insertOrUpdate(std::vector
 {
     assert(elem.elementType != TimelineElement::Undefined);
 
-    while (it != m_elements.end() && (*it) < elem) {
+    while (it != m_elements.end() && (*it) != elem && (*it) < elem) {
         ++it;
     }
 
@@ -503,12 +503,23 @@ void TimelineModel::updateInformationElements()
         newCountry.setTimeZone(previousCountry.timeZone(), (*it).dt);
         newCountry.setTimeZone(timeZone((*it).endDateTime()), (*it).dt);
         if (newCountry == previousCountry) {
+            if (newCountry.timeZone().isValid()) {
+                previousCountry = newCountry;
+            }
             ++it;
             continue;
         }
         if (!(newCountry == homeCountry) || newCountry.hasRelevantTimeZoneChange(previousCountry)) {
             // for location changes, we want this after the corresponding element
-            const auto dt = (*it).isLocationChange() ? (*it).endDateTime() : (*it).dt;
+            auto dt = (*it).isLocationChange() ? (*it).endDateTime() : (*it).dt;
+            if ((*it).isReservation()) {
+                const auto res = m_resMgr->reservation((*it).batchId());
+                if (!SortUtil::hasEndTime(res) && SortUtil::hasStartTime(res)) {
+                    // pick a less aggressive insertion point for elements without an end time
+                    // (by default we'd get end of day as the end time, which can put this after subsequent elements)
+                    dt = SortUtil::startDateTime(res).addSecs(15 * 60);
+                }
+            }
             it = insertOrUpdate(it, TimelineElement{this, TimelineElement::LocationInfo, dt, QVariant::fromValue(newCountry)});
         }
 
@@ -792,12 +803,17 @@ void TimelineModel::transferChanged(const Transfer& transfer)
         return;
     }
 
+    TimelineElement elem(this, transfer);
     if (transfer.alignment() == Transfer::Before) {
         if (it != m_elements.begin()) {
             --it;
         }
+        // check for weather info elements between reservation and an already existing transfer
+        if (it != m_elements.begin() && (*it).elementType == TimelineElement::WeatherForecast && (*std::prev(it)) == elem) {
+            --it;
+        }
     }
-    insertOrUpdate(it, TimelineElement(this, transfer));
+    insertOrUpdate(it, std::move(elem));
 
     Q_EMIT todayRowChanged();
 }
